<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>CDayMonthView</name>
    <message>
        <source>Monday</source>
        <translation>pondělí</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>úterý</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>středa</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>čtvrtek</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>pátek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>neděle</translation>
    </message>
</context>
<context>
    <name>CDayWindow</name>
    <message>
        <source>Y</source>
        <translation>R</translation>
    </message>
    <message>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CGraphicsView</name>
    <message>
        <source>New Event</source>
        <translation>Nová událost</translation>
    </message>
</context>
<context>
    <name>CMonthGraphiview</name>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Mažete událost.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Opravdu chcete tuto událost smazat?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Chcete smazat všechny výskyty této události, nebo jen ten vybraný?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Smazat vše</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Smazat jen tuto událost</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Chcete smazat tento a všechny budoucí výskyty této události, nebo jen ten vybraný?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Smazat všechny budoucí události</translation>
    </message>
</context>
<context>
    <name>CMonthSchceduleNumButton</name>
    <message>
        <source>%1 more</source>
        <translation>%1 více</translation>
    </message>
</context>
<context>
    <name>CMonthView</name>
    <message>
        <source>New event</source>
        <translation>Nová událost</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation>Nová událost</translation>
    </message>
</context>
<context>
    <name>CMonthWindow</name>
    <message>
        <source>Y</source>
        <translation>R</translation>
    </message>
</context>
<context>
    <name>CMySchceduleView</name>
    <message>
        <source>You are deleting an event.</source>
        <translation>Mažete událost.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Opravdu chcete tuto událost smazat?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Chcete smazat všechny výskyty této události, nebo jen vybraný výskyt?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Smazat vše</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Smazat jen tuto událost</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Chcete smazat tento a všechny výskyty této události, nebo jen vybraný výskyt?</translation>
    </message>
    <message>
        <source>My Event</source>
        <translation>Moje událost</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Smazat všechny budoucí události</translation>
    </message>
</context>
<context>
    <name>CSchceduleDlg</name>
    <message>
        <source>New Event</source>
        <translation>Nová událost</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation>Upravit událost</translation>
    </message>
    <message>
        <source>All occurrences of a repeating event must have the same all-day status.</source>
        <translation>Je třeba, aby všechny výskyty opakující se události měly stejný stav „celý den“.</translation>
    </message>
    <message>
        <source>Do you want to change all occurrences?</source>
        <translation>Chcete změnit všechny výskyty?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Change All</source>
        <translation>Změnit vše</translation>
    </message>
    <message>
        <source>You are changing the repeating rule of this event.</source>
        <translation>Měníte pravidlo opakování této události.</translation>
    </message>
    <message>
        <source>You are changing a repeating event.</source>
        <translation>Měníte pravidlo opakující se události.</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
        <translation>Chcete změnit jen tento výskyt události, nebo všechny výskyty?</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Vše</translation>
    </message>
    <message>
        <source>Only This Event</source>
        <translation>Jen tato událost</translation>
    </message>
    <message>
        <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
        <translation>Chcete změnit jen tento výskyt události, nebo tento a všechny budoucí výskyty?</translation>
    </message>
    <message>
        <source>All Future Events</source>
        <translation>Všechny budoucí události</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nikdy</translation>
    </message>
    <message>
        <source>At time of event</source>
        <translation>V čase události</translation>
    </message>
    <message>
        <source>15 minutes before</source>
        <translation>15 minut před</translation>
    </message>
    <message>
        <source>30 minutes before</source>
        <translation>30 minut před</translation>
    </message>
    <message>
        <source>1 hour before</source>
        <translation>1 hodinu před</translation>
    </message>
    <message>
        <source>1 day before</source>
        <translation>1 den před</translation>
    </message>
    <message>
        <source>2 days before</source>
        <translation>2 dny před</translation>
    </message>
    <message>
        <source>1 week before</source>
        <translation>1 týden před</translation>
    </message>
    <message>
        <source>On start day (9:00 AM)</source>
        <translation>V den začátku (9:00 dop.)</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>All Day:</source>
        <translation>Celý den:</translation>
    </message>
    <message>
        <source>Remind Me:</source>
        <translation>Připomenout:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Opakovat:</translation>
    </message>
    <message>
        <source>Daily</source>
        <translation>Denně</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Všední dny</translation>
    </message>
    <message>
        <source>Weekly</source>
        <translation>Týdně</translation>
    </message>
    <message>
        <source>Monthly</source>
        <translation>Měsíčně</translation>
    </message>
    <message>
        <source>Yearly</source>
        <translation>Ročně</translation>
    </message>
    <message>
        <source>End Repeat:</source>
        <translation>Ukončit opakování:</translation>
    </message>
    <message>
        <source>After</source>
        <translation>Po</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Zapnuto</translation>
    </message>
    <message>
        <source>time(s)</source>
        <translation>krát</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>New event</source>
        <translation>Nová událost</translation>
    </message>
    <message>
        <source>End time must be greater than start time</source>
        <translation>Je třeba, aby okamžik konce následoval až po okamžiku začátku</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation>Celý den</translation>
    </message>
    <message>
        <source>Starts</source>
        <translation>Začíná</translation>
    </message>
    <message>
        <source>Ends</source>
        <translation>Končí</translation>
    </message>
    <message>
        <source>Remind Me</source>
        <translation>Připomenout</translation>
    </message>
    <message>
        <source>Repeat</source>
        <translation>Opakování</translation>
    </message>
    <message>
        <source>End Repeat</source>
        <translation>Ukončit opakování</translation>
    </message>
    <message>
        <source>Ends:</source>
        <translation>Končí:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Popis:</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Starts:</source>
        <translation>Začíná:</translation>
    </message>
    <message>
        <source>Work</source>
        <translation>Práce</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Soukromé</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Ostatní</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchDateItem</name>
    <message>
        <source>Y</source>
        <translation>R</translation>
    </message>
    <message>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchItem</name>
    <message>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Mažete událost.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Opravdu chcete tuto událost smazat?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Chcete smazat všechny výskyty této události, nebo jen vybraný výskyt?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Smazat vše</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Smazat jen tuto událost</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Chcete smazat tento a všechny výskyty této události, nebo jen vybraný výskyt?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Smazat všechny budoucí události</translation>
    </message>
    <message>
        <source>All Day</source>
        <translation>Celý den</translation>
    </message>
</context>
<context>
    <name>CSchceduleSearchView</name>
    <message>
        <source>No search results</source>
        <translation>Nic nenalezeno</translation>
    </message>
</context>
<context>
    <name>CScheduleView</name>
    <message>
        <source>ALL DAY</source>
        <translation>CELÝ DEN</translation>
    </message>
</context>
<context>
    <name>CWeekWindow</name>
    <message>
        <source>Week</source>
        <translation>Týden</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>R</translation>
    </message>
</context>
<context>
    <name>CYearSchceduleItem</name>
    <message>
        <source>All Day</source>
        <translation>Celý den</translation>
    </message>
</context>
<context>
    <name>CYearSchceduleView</name>
    <message>
        <source>All Day</source>
        <translation>Celý den</translation>
    </message>
    <message>
        <source>No event</source>
        <translation>Žádná událost</translation>
    </message>
</context>
<context>
    <name>CYearWindow</name>
    <message>
        <source>Y</source>
        <translation>R</translation>
    </message>
</context>
<context>
    <name>CalendarWindow</name>
    <message>
        <source>Calendar</source>
        <translation>Kalendář</translation>
    </message>
    <message>
        <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
        <translation>Kalendář slouží k zobrazování dat a také jako chytrý každodenní plánovač všeho v životě.</translation>
    </message>
</context>
<context>
    <name>Calendarmainwindow</name>
    <message>
        <source>Calendar</source>
        <translation>Kalendář</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>R</translation>
    </message>
    <message>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <source>W</source>
        <translation>T</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
</context>
<context>
    <name>CenterWidget</name>
    <message>
        <source>All Day</source>
        <translation>Celý den</translation>
    </message>
</context>
<context>
    <name>DragInfoGraphicsView</name>
    <message>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>New event</source>
        <translation>Nová událost</translation>
    </message>
    <message>
        <source>You are deleting an event.</source>
        <translation>Mažete událost.</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this event?</source>
        <translation>Opravdu chcete tuto událost smazat?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
        <translation>Chcete smazat všechny výskyty této události, nebo jen ten vybraný?</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Smazat vše</translation>
    </message>
    <message>
        <source>Delete Only This Event</source>
        <translation>Smazat jen tuto událost</translation>
    </message>
    <message>
        <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
        <translation>Chcete smazat tento a všechny budoucí výskyty této události, nebo jen ten vybraný?</translation>
    </message>
    <message>
        <source>Delete All Future Events</source>
        <translation>Smazat všechny budoucí události</translation>
    </message>
    <message>
        <source>New Event</source>
        <translation>Nová událost</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation>Dnes</translation>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation>Dnes</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Delete event</source>
        <translation>Smazat událost</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Vyjmout</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Vybrat vše</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>YearFrame</name>
    <message>
        <source>Y</source>
        <translation>R</translation>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation>Dnes</translation>
    </message>
</context>
</TS>